@@ -1,6 +1,10 @@
-#[derive(Debug)]
+use crate::console::Verbosity;
+
+#[derive(Debug, Default)]
 /// Settings applied for a DirectoryPatcher run
 pub struct Settings {
+    /// Control verbosity of ruplacer's console output
+    pub verbosity: Verbosity,
     /// If true, do not write changes to the file system (default: false)
     pub dry_run: bool,
     /// If true, also patch hidden files (default: false)
@@ -12,15 +16,3 @@ pub struct Settings {
     /// List of file types to ignore (default: empty)
     pub ignored_file_types: Vec<String>,
 }
-
-impl Default for Settings {
-    fn default() -> Self {
-        Self {
-            dry_run: false,
-            hidden: false,
-            ignored: false,
-            selected_file_types: vec![],
-            ignored_file_types: vec![],
-        }
-    }
-}
